==> frezka_admin_panel_updated_files_v3.0.0.zip: lang/fr/booking.php <==
<?php

return [
    'title' => 'Réservations',
    'singular_title' => 'Réservation',
    'lbl_phone' => 'Téléphone :',
    'lbl_e-mail' => 'E-mail :',
    'lbl_with' => 'Avec',
    'lbl_at' => 'À :',
    'lbl_note' => 'Remarque',
    'lbl_sub_tot' => 'Sous-total :',
    'lbl_got_to_payment' => 'Aller au paiement',
    'lbl_complete_now' => 'Terminer maintenant',
    'lbl_payment' => 'Paiement',
    'lbl_pay_now' => 'Payer maintenant',
    'lbl_is_paid' => 'Payé',
    'lbl_add_service' => 'Ajouter un service',
    'lbl_add_package' => 'Ajouter un package',
    'lbl_date' => 'Date',
    'lbl_customer_name' => 'Nom du client',
    'lbl_amount' => 'Montant',
    'lbl_duration' => 'Durée',
    'lbl_staff_name' => 'Nom du personnel',
    'lbl_services' => 'Services',
    'lbl_update_at' => 'Mis à jour à',
    'lbl_status' => 'Statut',
    'booking_update' => 'Réservation mise à jour',
    'booking_status_list' => 'Liste des statuts de réservation',
    'search_booking' => 'Résultats de la recherche pour les réservations.',
    'booking_detail' => 'Détails de la réservation',
    'booking_list' => 'Liste de réservation',
    'status_update' => 'Le statut a été mis à jour !',
    'booking_delete' => 'Supprimé avec succès',
    'booking_not_found' => 'Réservation non trouvée',
    'payment_done' => 'Paiement réussi',
    'booking_branch' => 'LISTE_DE_BRANCHES',
    'booking_timeslot' => 'LISTE_DE_TRANCHE_HORAIRE',
    'booking_category' => 'LISTE_DE_CATÉGORIES',
    'booking_sevice' => 'LISTE_DE_SERVICES',
    'booking_employee' => 'LISTE_D\'EMPLOYÉS',
    'booking_create' => 'RÉSERVATION_CRÉÉE',
    'booking_action_invalid' => 'Action non valide',
    'booking_service_update' => 'Mise à jour du service de réservation réussie',
    'payment_successfull' => 'Paiement terminé avec succès',
    'create_form' => 'Le formulaire :form a été créé avec succès',
    'lbl_action' => 'Action',
    'lbl_new_appointment' => 'Nouveau rendez-vous',
    'lbl_appointment' => 'Rendez-vous',
    'lbl_advanced_filter' => 'Filtre avancé',
    'lbl_booking_date' => 'Date de réservation',
    'lbl_customer_name' => 'Nom du client',
    'lbl_staff_name' => 'Nom du personnel',
    'lbl_services' => 'Services',
    'lbl_payment_status' => 'État du paiement',
    'download_invoice' => 'Télécharger la facture',
    'name' => 'nom',
    'phone' => 'téléphone',
    'email' => 'E-mail',
    'payment_method' => 'Mode de paiement',
    'customer_info' => 'Informations sur le client',
    'services' => 'Services ',
    'unit_price' => 'Prix ​​unitaire',
    'qty' => 'Quantité',
    'total_price' => 'Prix ​​total',
    'tips' => 'Conseils',
    'tax' => 'Impôt',
    'grand-total' => 'Total',
    'sub_total' => 'Sous-total',
    'products' => 'Produits',
    'invoice_data' => 'Données de la facture',
    'coupondiscount' => 'Remise de coupon',
    'grand_total' => 'Total général',
    'tips' => 'Pourboires',
    'billing_address' => 'Adresse de facturation'
    
];

==> frezka_admin_panel_updated_files_v3.3.0.zip: lang/fr/booking.php <==
<?php

return [
    'title' => 'Réservations',
    'singular_title' => 'Réservation',
    'lbl_phone' => 'Téléphone :',
    'lbl_e-mail' => 'E-mail :',
    'lbl_with' => 'Avec',
    'lbl_at' => 'À :',
    'lbl_note' => 'Remarque',
    'lbl_sub_tot' => 'Sous-total :',
    'lbl_got_to_payment' => 'Aller au paiement',
    'lbl_complete_now' => 'Terminer maintenant',
    'lbl_payment' => 'Paiement',
    'lbl_pay_now' => 'Payer maintenant',
    'lbl_is_paid' => 'Payé',
    'lbl_add_service' => 'Ajouter un service',
    'lbl_add_package' => 'Ajouter un package',
    'lbl_date' => 'Date',
    'lbl_customer_name' => 'Client',
    'lbl_amount' => 'Montant',
    'lbl_duration' => 'Durée',
    'lbl_staff_name' => 'Personnel',
    'lbl_services' => 'Services',
    'lbl_update_at' => 'Mis à jour à',
    'lbl_status' => 'Statut',
    'booking_update' => 'Réservation mise à jour',
    'booking_status_list' => 'Liste des statuts de réservation',
    'search_booking' => 'Résultats de la recherche pour les réservations.',
    'booking_detail' => 'Détails de la réservation',
    'booking_list' => 'Liste de réservation',
    'status_update' => 'Le statut a été mis à jour !',
    'booking_delete' => 'Supprimé avec succès',
    'booking_not_found' => 'Réservation non trouvée',
    'payment_done' => 'Paiement réussi',
    'booking_branch' => 'LISTE_DE_BRANCHES',
    'booking_timeslot' => 'LISTE_DE_TRANCHE_HORAIRE',
    'booking_category' => 'LISTE_DE_CATÉGORIES',
    'booking_sevice' => 'LISTE_DE_SERVICES',
    'booking_employee' => 'LISTE_D\'EMPLOYÉS',
    'booking_create' => 'RÉSERVATION_CRÉÉE',
    'booking_action_invalid' => 'Action non valide',
    'booking_service_update' => 'Mise à jour du service de réservation réussie',
    'payment_successfull' => 'Paiement terminé avec succès',
    'create_form' => 'Le formulaire :form a été créé avec succès',
    'lbl_action' => 'Action',
    'lbl_new_appointment' => 'Nouveau rendez-vous',
    'lbl_appointment' => 'Rendez-vous',
    'lbl_advanced_filter' => 'Filtre avancé',
    'lbl_booking_date' => 'Date de réservation',
    'lbl_customer_name' => 'Nom du client',
    'lbl_staff_name' => 'Nom du personnel',
    'lbl_services' => 'Services',
    'lbl_payment_status' => 'État du paiement',
    'download_invoice' => 'la facture',
    'name' => 'nom',
    'phone' => 'téléphone',
    'email' => 'E-mail',
    'payment_method' => 'Mode de paiement',
    'customer_info' => 'Informations sur le client',
    'services' => 'Services ',
    'unit_price' => 'Prix ​​unitaire',
    'qty' => 'Quantité',
    'total_price' => 'Prix ​​total',
    'tips' => 'Conseils',
    'tax' => 'Impôt',
    'grand-total' => 'Total',
    'sub_total' => 'Sous-total',
    'products' => 'Produits',
    'invoice_data' => 'Données de la facture',
    'coupondiscount' => 'Remise de coupon',
    'grand_total' => 'Total général',
    'tips' => 'Pourboires',
    'billing_address' => 'Adresse de facturation',
    'grand_total' => 'Total Général :',
    'lbl_packages' => 'Forfaits',
    'lbl_add_more' => 'Ajouter Plus',
    'lbl_packages_detail' => 'Détails des Forfaits',
    'lbl_package_available' => 'Forfaits Disponibles',
    'lbl_package_active' => 'Votre forfait est toujours actif',
    'lbl_view_all' => 'Voir Tout',
    'booking_date' => 'Sélectionner la Date de Réservation',
    'customer_name' => 'Sélectionner le Nom du Client',
    'staff_name' => 'Sélectionner le Nom du Personnel',
    'select_service' => 'Sélectionner les Services',
    'branch_name' => 'Nom de la Succursale',
    'invoice_time' => 'Heure de la Facture',
    'payment_type' => 'Type de paiement',
    'service_amount' => 'Montant du service',
    'product_amount'=> 'Montant du produit',
    'package_amount' => 'Montant du package',
    'tip_amount' => 'Pourboire',
    'total' => 'Total',
    'final_total' => 'Total final',
    'booking_detail' => 'Détails de la réservation',
    'booked_on' => 'Réservé le',
    'booked_by' => 'Réservé par',
    'updated_on' => 'Mis à jour le',
    'updated_by' => 'Mis à jour par',
    'sale' => 'Vente #0',
    'with' => 'Avec',
    'sold_by' => 'Vendu par',
    'client_since' => 'Client depuis',
    'coupon_discount' => 'Réduction du coupon',

];
